/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry_overlay.api;

/**
 * Default values used by Petals Registry Overlay client and server.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class Constants {

    /**
     * Default listening port of a node
     */
    public static final int DEFAULT_PORT = 7900;

    /**
     * Default group for credentials. The value is aligned with the value contains in the default topology.
     */
    public static final String DEFAULT_CREDENTIALS_GROUP = "default-sample";

    /**
     * Default password for credentials. The value is aligned with the value contains in the default topology.
     */
    public static final String DEFAULT_CREDENTIALS_PASSWORD = "s3cr3t";

    /**
     * Name of the member property about the member identifier
     */
    public static final String MEMBER_PROPERTY_NAME_MEMBER_ID = "petals.registry.overlay.member.local-identifier";

    /**
     * Name of the member property about the configuration of the JMX port
     */
    public static final String MEMBER_PROPERTY_NAME_JMX_PORT = "petals.registry.overlay.member.jmx.port";

    /**
     * Name of the member property about the configuration of the username of JMX credentials
     */
    public static final String MEMBER_PROPERTY_NAME_JMX_USER = "petals.registry.overlay.member.jmx.user";

    /**
     * Name of the member property about the configuration of the password of JMX credentials
     */
    public static final String MEMBER_PROPERTY_NAME_JMX_PWD = "petals.registry.overlay.member.jmx.password";

    /**
     * Name of the member property about the configuration of the activation of the JMX Connector. This property has
     * been introduced to not activate the JMX connector when the Petals Registry Overlay is embedded as a Petals ESB
     * extension.
     */
    public static final String MEMBER_PROPERTY_NAME_ENABLE_JMX_CONNECTOR = "petals.registry.overlay.member.jmx.server.connector.disable";

    /**
     * Name of the member property about the wait time to acquire a lock on the client maps
     */
    public static final String MEMBER_PROPERTY_NAME_CLIENTSMAP_LOCK_WAITTIME = "petals.registry.overlay.member.clients-map.lock.wait-time";

    /**
     * Default value of the JMX port
     */
    public static final int MEMBER_PROPERTY_DEFAULT_JMX_PORT = 7750;

    /**
     * Default value of the username of JMX credentials
     */
    public static final String MEMBER_PROPERTY_DEFAULT_JMX_USER = "petals";

    /**
     * Default value of the password of JMX credentials
     */
    public static final String MEMBER_PROPERTY_DEFAULT_JMX_PWD = "petals";

    private Constants() {
        // NOP: Utility class --> No constructor
    }

}
